@@ -1,21 +1,8 @@
 /*
-   Copyright (C) 2003-2005 George Staikos <staikos@kde.org>
-   Copyright (C) 2005 Isaac Clerencia <isaac@warp.es>
+    SPDX-FileCopyrightText: 2003-2005 George Staikos <staikos@kde.org>
+    SPDX-FileCopyrightText: 2005 Isaac Clerencia <isaac@warp.es>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kwalleteditor.h"
@@ -222,7 +209,7 @@ void KWalletEditor::createActions(KActionCollection *actionCollection)
 
     _copyPassAction = actionCollection->addAction(QStringLiteral("copy_action"));
     _copyPassAction->setText(i18n("&Copy"));
-    actionCollection->setDefaultShortcut(_copyPassAction, Qt::Key_C + Qt::CTRL);
+    actionCollection->setDefaultShortcut(_copyPassAction, Qt::Key_C | Qt::CTRL);
     _copyPassAction->setEnabled(false);
 
     _newEntryAction = actionCollection->addAction(QStringLiteral("new_entry"));
